@@ -16,7 +16,6 @@ from ckan.tests import factories
 @pytest.mark.ckan_config('ckanext.twitter.debug', True)
 @pytest.mark.usefixtures('clean_db', 'with_plugins', 'with_request_context')
 class TestController(object):
-
     def test_url_created(self):
         url = toolkit.url_for('tweet.send', package_id='not-a-real-id')
         assert url == '/dataset/not-a-real-id/tweet'
@@ -27,9 +26,7 @@ class TestController(object):
         assert response.status_code, 200
 
     def test_debug_post_tweet(self, app):
-        dataset = factories.Dataset(
-            notes='Test dataset'
-        )
+        dataset = factories.Dataset(notes='Test dataset')
         url = toolkit.url_for('tweet.send', package_id=dataset['id'])
         response = app.post(url, data={'tweet_text': 'this is a test tweet'})
         body = json.loads(response.body)
