@@ -9,16 +9,17 @@ from ckan.tests import factories
 from ckan.tests.helpers import call_action
 from unittest.mock import patch
 
-from ckanext.twitter.lib import (parsers as twitter_parsers)
+from ckanext.twitter.lib import parsers as twitter_parsers
 
 
 @pytest.mark.filterwarnings('ignore::sqlalchemy.exc.SADeprecationWarning')
 @pytest.mark.ckan_config('ckan.plugins', 'datastore twitter')
 @pytest.mark.ckan_config('ckanext.twitter.debug', True)
-@pytest.mark.usefixtures('clean_db', 'clean_datastore', 'with_plugins', 'with_request_context')
+@pytest.mark.usefixtures(
+    'clean_db', 'clean_datastore', 'with_plugins', 'with_request_context'
+)
 @patch('ckanext.twitter.plugin.session')
 class TestDatasetMetadata(object):
-
     def test_gets_dataset_number_of_records_if_has_records(self, mock_session):
         package = factories.Dataset()
         resource = factories.Resource(package_id=package['id'], url_type='datastore')
